feijoa.storages package
=======================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   feijoa.storages.rdb

Submodules
----------

feijoa.storages.storage module
------------------------------

.. automodule:: feijoa.storages.storage
   :members:
   :undoc-members:
   :show-inheritance:

feijoa.storages.tiny module
---------------------------

.. automodule:: feijoa.storages.tiny
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: feijoa.storages
   :members:
   :undoc-members:
   :show-inheritance:
